##  Example
The example below explains how to navigate the dashboard using custom views grouped into the following categories:
  * **Region** : "America," "Europe," and "Asia"
  * **Executive team** : “CTO," "CIO," and "CEO"
  * **Business unit** : "Sales," "HR," and "IT"


Follow these steps:
  1. To narrow the data scope and focus on insights for a specific region, select a view from the "Region" category in the upper-left corner of the dashboard, such as "America." This action filters all KPIs on the dashboard for that region. KPI cards display how the current data compares to a past period (by default, the last quarter).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio84236870051d40bc878be8630a2f6514_LowRes.png)
Selecting a View
  2. On the dashboard, select the KPI you want to analyze, such as "Technical fit of applications."
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa07522950784424f9ef9b30f283b565e_LowRes.png)
Selecting a KPI
  3. In the overlay that appears, from the Pivot by list under Details, select the category for which you want to view the KPI breakdown, such as "Executive team." With two filters applied, the chart presents datasets specific to the American region and the executive team.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio53ab63646c874686ac895f873840da21_LowRes.png)
Selecting a Filter to View the KPI Breakdown
  4. To view insights for a specific dataset, select it on the chart, such as "CEO." This filters data for the CEO department within the executive team in the American region. Analyze how to improve the KPI and make data-driven decisions. From here, you can navigate to the inventory to perform actions on fact sheets with identified areas for improvement.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio93c17d52fbd24039a17e79cc4f6362ff_LowRes.png)
Selecting a Dataset to View Data Insights


YesNo
Send
